pub struct BufferedUpload { /* private fields */ }Expand description
An uploaded file fully buffered in memory as a sequence of chunks.
During multipart parsing all chunks are collected into memory before the
struct is returned. The chunk() and
into_reader() methods replay from this buffer.
Implementations
Sourceimpl BufferedUpload
impl BufferedUpload
Sourcepub fn content_type(&self) -> &str
pub fn content_type(&self) -> &str
The MIME content type.
Sourcepub async fn chunk(&mut self) -> Option<Result<Bytes, Error>>
pub async fn chunk(&mut self) -> Option<Result<Bytes, Error>>
Read the next chunk. Returns None when all chunks are consumed.