pub struct UploadedFile { /* private fields */ }Expand description
An uploaded file fully buffered in memory as a single contiguous buffer.
UploadedFile holds all bytes in a single bytes::Bytes buffer after the
multipart field has been drained. Use BufferedUpload
instead when you need to write to storage via a chunked reader API
(e.g. BufferedUpload::into_reader).
Implementations